@@ -163,13 +163,11 @@ class GraphEntity(AbstractEntity):
     }
 
     def __init__(self, g: Graph, g_set: GraphSet, res: URIRef = None, res_type: URIRef = None,
-                 resp_agent: str = None, source_agent: str = None, source: str = None,
-                 count: str = None, label: str = None, short_name: str = "",
-                 preexisting_graph: Graph = None) -> None:
+                 resp_agent: str = None, source: str = None, count: str = None, label: str = None,
+                 short_name: str = "", preexisting_graph: Graph = None) -> None:
         super(GraphEntity, self).__init__()
         self.g: Graph = g
         self.resp_agent: str = resp_agent
-        self.source_agent: str = source_agent
         self.source: str = source
         self.short_name: str = short_name
         self.g_set: GraphSet = g_set
