@@ -17,6 +17,8 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
+from SPARQLWrapper import SPARQLWrapper, RDFXML
+
 from oc_ocdm.reader import Reader
 from oc_ocdm.abstract_set import AbstractSet
 from oc_ocdm.support.support import get_count
@@ -25,7 +27,7 @@ if TYPE_CHECKING:
     from typing import Dict, ClassVar, Tuple, Optional, List
     from rdflib.query import Result
 
-from rdflib import Graph, Namespace, URIRef, ConjunctiveGraph
+from rdflib import Graph, Namespace, URIRef
 
 from oc_ocdm.graph.graph_entity import GraphEntity
 from oc_ocdm.counter_handler.counter_handler import CounterHandler
@@ -94,104 +96,105 @@ class GraphSet(AbstractSet):
             return self.res_to_entity[res]
 
     # Add resources related to bibliographic entities
-    def add_an(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> ReferenceAnnotation:
+    def add_an(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> ReferenceAnnotation:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_an, res, "an")
         return ReferenceAnnotation(cur_g, self, res, GraphEntity.iri_note,
-                                   resp_agent, source_agent, source, count,
-                                   label, "an", preexisting_graph)
+                                   resp_agent, source, count, label, "an",
+                                   preexisting_graph)
 
-    def add_ar(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> AgentRole:
+    def add_ar(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> AgentRole:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_ar, res, "ar")
-        return AgentRole(cur_g, self, res, GraphEntity.iri_role_in_time, resp_agent,
-                         source_agent, source, count, label, "ar", preexisting_graph)
+        return AgentRole(cur_g, self, res, GraphEntity.iri_role_in_time,
+                         resp_agent, source, count, label, "ar",
+                         preexisting_graph)
 
-    def add_be(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> BibliographicReference:
+    def add_be(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> BibliographicReference:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_be, res, "be")
         return BibliographicReference(cur_g, self, res,
                                       GraphEntity.iri_bibliographic_reference,
-                                      resp_agent, source_agent, source, count,
-                                      label, "be", preexisting_graph)
+                                      resp_agent, source, count, label, "be",
+                                      preexisting_graph)
 
-    def add_br(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> BibliographicResource:
+    def add_br(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> BibliographicResource:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_br, res, "br")
         return BibliographicResource(cur_g, self, res, GraphEntity.iri_expression,
-                                     resp_agent, source_agent, source, count,
-                                     label, "br", preexisting_graph)
+                                     resp_agent, source, count, label, "br",
+                                     preexisting_graph)
 
-    def add_ci(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> Citation:
+    def add_ci(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> Citation:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_ci, res, "ci")
         return Citation(cur_g, self, res, GraphEntity.iri_citation,
-                        resp_agent, source_agent, source, count,
-                        label, "ci", preexisting_graph)
+                        resp_agent, source, count, label, "ci",
+                        preexisting_graph)
 
-    def add_de(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> DiscourseElement:
+    def add_de(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> DiscourseElement:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_de, res, "de")
         return DiscourseElement(cur_g, self, res, GraphEntity.iri_discourse_element,
-                                resp_agent, source_agent, source, count,
-                                label, "de", preexisting_graph)
+                                resp_agent, source, count, label, "de",
+                                preexisting_graph)
 
-    def add_id(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> Identifier:
+    def add_id(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> Identifier:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_id, res, "id")
         return Identifier(cur_g, self, res, GraphEntity.iri_identifier,
-                          resp_agent, source_agent, source, count,
-                          label, "id", preexisting_graph)
+                          resp_agent, source, count, label, "id",
+                          preexisting_graph)
 
-    def add_pl(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> PointerList:
+    def add_pl(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> PointerList:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_pl, res, "pl")
         return PointerList(cur_g, self, res, GraphEntity.iri_singleloc_pointer_list,
-                           resp_agent, source_agent, source, count,
-                           label, "pl", preexisting_graph)
+                           resp_agent, source, count, label, "pl",
+                           preexisting_graph)
 
-    def add_rp(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> ReferencePointer:
+    def add_rp(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> ReferencePointer:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_rp, res, "rp")
         return ReferencePointer(cur_g, self, res, GraphEntity.iri_intextref_pointer,
-                                resp_agent, source_agent, source, count,
-                                label, "rp", preexisting_graph)
+                                resp_agent, source, count, label, "rp",
+                                preexisting_graph)
 
-    def add_ra(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> ResponsibleAgent:
+    def add_ra(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> ResponsibleAgent:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_ra, res, "ra")
         return ResponsibleAgent(cur_g, self, res, GraphEntity.iri_agent,
-                                resp_agent, source_agent, source, count,
-                                label, "ra", preexisting_graph)
+                                resp_agent, source, count, label, "ra",
+                                preexisting_graph)
 
-    def add_re(self, resp_agent: str, source_agent: str = None, source: str = None,
-               res: URIRef = None, preexisting_graph: Graph = None) -> ResourceEmbodiment:
+    def add_re(self, resp_agent: str, source: str = None, res: URIRef = None,
+               preexisting_graph: Graph = None) -> ResourceEmbodiment:
         if res is not None and res in self.res_to_entity:
             return self.res_to_entity[res]
         cur_g, count, label = self._add(self.g_re, res, "re")
         return ResourceEmbodiment(cur_g, self, res, GraphEntity.iri_manifestation,
-                                  resp_agent, source_agent, source, count,
-                                  label, "re", preexisting_graph)
+                                  resp_agent, source, count, label, "re",
+                                  preexisting_graph)
 
     def _add(self, graph_url: str, res: URIRef, short_name: str) -> Tuple[Graph, Optional[str], Optional[str]]:
         cur_g: Graph = Graph(identifier=graph_url)
@@ -216,18 +219,21 @@ class GraphSet(AbstractSet):
 
         return cur_g, count, label
 
-    def sync_with_triplestore(self, ts_url: str) -> None:
-        ts: ConjunctiveGraph = ConjunctiveGraph()
-        ts.open((ts_url, ts_url))
+    def sync_with_triplestore(self, ts_url: str, resp_agent: str) -> None:
+        sparql: SPARQLWrapper = SPARQLWrapper(ts_url)
+
         for entity_res, entity in self.res_to_entity.items():
             if entity.to_be_deleted:
                 query: str = f"CONSTRUCT {{?s ?p ?o}} WHERE {{?s ?p ?o ; ?p_1 <{entity_res}>}}"
-                result: Result = ts.query(query)
+                sparql.setQuery(query)
+                sparql.setMethod('POST')
+                sparql.setReturnFormat(RDFXML)
+
+                result: Result = sparql.query().convert()
                 if result is not None:
-                    imported_entities: List[GraphEntity] = Reader.import_entities_from_graph(self, result.graph)
+                    imported_entities: List[GraphEntity] = Reader.import_entities_from_graph(self, result, resp_agent)
                     for imported_entity in imported_entities:
                         imported_entity.g.remove((imported_entity.res, None, entity_res))
-        ts.close()
 
     def commit_changes(self):
         for res, entity in self.res_to_entity.items():
